package com.perforce.reviewer;

import com.perforce.api.*;

/**
 * Change listening interface. Classes that implement this interface
 * can be used by the <code>Reviewer</code> on the appropirate
 * changelists. The implementing class must also have a no-argument
 * constructor.
 *
 * @see Reviewer
 * @author <a href="mailto:david@markley.cc">David Markley</a>
 * @version $Date: 2002/01/11 $ $Revision: #2 $
 */
public interface ChangeListener {

  /**
   * Sets the environment used by the implementing class. This is
   * called after the class is instantiated by the <code>Reviewer</code>
   * using the no-argument constructor.
   *
   * @see Reviewer
   */
  public void setEnv(Env env);

  /**
   * Handles a changelist with an associated list of users. This is
   * called by the <code>Reviewer</code> if there is a match found
   * with the underlying class. The user is typically filled with
   * all users that are reviewing the change except those that
   * had specific classes associated with their Id. The user array
   * may also be null.
   *
   * @see Reviewer
   * @param chng  Current changelist being reviewed/handled.
   * @param users Users that are reviewing the current change (or null).
   */
  public void handleChange(Change chng, User[] users);
}
